@@ -460,6 +460,13 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                           op_cur->code = SPVM_OP_C_CODE_NULL;
                         }
                       }
+                      else if (op_cur->first->code == SPVM_OP_C_CODE_ASSIGN) {
+                        op_cur->code = SPVM_OP_C_CODE_NULL;
+                      }
+                      else if (op_cur->first->code == SPVM_OP_C_CODE_VAR) {
+                        op_cur->code = SPVM_OP_C_CODE_NULL;
+                        op_cur->first->code = SPVM_OP_C_CODE_NULL;
+                      }
                       break;
                     }
                     case SPVM_OP_C_CODE_DEFAULT: {
@@ -889,7 +896,7 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                         my_var->index = my_var_length++;
                         
                         // op my_var
-                        SPVM_OP* op_my_var = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_MY_VAR, op_cur->file, op_cur->line);
+                        SPVM_OP* op_my_var = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_MY, op_cur->file, op_cur->line);
                         op_my_var->uv.my_var = my_var;
                         
                         // Add my var
@@ -1011,53 +1018,48 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                     }
                     case SPVM_OP_C_CODE_ASSIGN: {
                       
-                      SPVM_TYPE* first_type = SPVM_OP_get_type(compiler, op_cur->first);
-                      SPVM_TYPE* last_type = SPVM_OP_get_type(compiler, op_cur->last);
-                      
-                      // Type inference
-                      if (!first_type) {
-                        SPVM_OP* op_var = op_cur->first;
-                        SPVM_MY_VAR* my_var = op_var->uv.var->op_my_var->uv.my_var;
-                        first_type = SPVM_OP_get_type(compiler, my_var->op_term_type_inference);
+                      // Check left term
+                      if (op_cur->first->code == SPVM_OP_C_CODE_VAR
+                        || op_cur->first->code == SPVM_OP_C_CODE_ARRAY_ELEM
+                        || op_cur->first->code == SPVM_OP_C_CODE_CALL_FIELD
+                        || op_cur->first->code == SPVM_OP_C_CODE_EXCEPTION_VAR
+                      )
+                      {
+                        SPVM_TYPE* first_type = SPVM_OP_get_type(compiler, op_cur->first);
+                        SPVM_TYPE* last_type = SPVM_OP_get_type(compiler, op_cur->last);
                         
-                        if (first_type) {
-                          SPVM_OP* op_type = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_TYPE, op_cur->file, op_cur->line);
-                          op_type->uv.type = first_type;
-                          my_var->op_type = op_type;
+                        // Type inference
+                        if (!first_type) {
+                          SPVM_OP* op_var = op_cur->first;
+                          SPVM_MY_VAR* my_var = op_var->uv.var->op_my_var->uv.my_var;
+                          first_type = last_type;
+                          
+                          if (last_type) {
+                            SPVM_OP* op_type = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_TYPE, op_cur->file, op_cur->line);
+                            op_type->uv.type = last_type;
+                            my_var->op_type = op_type;
+                          }
+                          else {
+                            SPVM_yyerror_format(compiler, "Type can't be detected at %s line %d\n", op_cur->first->file, op_cur->first->line);
+                            compiler->fatal_error = 1;
+                            return;
+                          }
                         }
-                        else {
-                          SPVM_yyerror_format(compiler, "Type can't be detected at %s line %d\n", op_cur->first->file, op_cur->first->line);
+                        
+                        // It is OK that left type is object and right is undef
+                        if (!SPVM_TYPE_is_numeric(compiler, first_type) && !last_type) {
+                          // OK
+                        }
+                        // Invalid type
+                        else if (first_type->id != last_type->id) {
+                          SPVM_yyerror_format(compiler, "Invalid type value is assigned at %s line %d\n", op_cur->file, op_cur->line);
                           compiler->fatal_error = 1;
                           return;
                         }
                       }
-                      
-                      // It is OK that left type is object and right is undef
-                      if (!SPVM_TYPE_is_numeric(compiler, first_type) && !last_type) {
-                        // OK
-                      }
-                      // Invalid type
-                      else if (first_type->id != last_type->id) {
-                        SPVM_yyerror_format(compiler, "Invalid type value is assigned at %s line %d\n", op_cur->file, op_cur->line);
-                        compiler->fatal_error = 1;
-                        return;
-                      }
-                      
-                      // Insert var op
-                      if (op_cur->last->code == SPVM_OP_C_CODE_ASSIGN) {
-                        SPVM_OP* op_var = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_VAR, op_cur->file, op_cur->line);
-                        op_var->uv.var = op_cur->last->first->uv.var;
-                        
-                        SPVM_OP* op_last_old = op_cur->last;
-                        
-                        op_last_old->sibparent = op_var;
-                        
-                        op_var->first = op_last_old;
-                        op_var->sibparent = op_cur;
-                        
-                        op_cur->last = op_var;
-                        
-                        op_cur->first->sibparent = op_var;
+                      else {
+                        SPVM_yyerror_format(compiler, "Can't assign to left at %s line %d\n", op_cur->file, op_cur->line);
+                        break;
                       }
                       
                       break;
@@ -1375,7 +1377,7 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                       }
                       break;
                     }
-                    case SPVM_OP_C_CODE_MY_VAR: {
+                    case SPVM_OP_C_CODE_MY: {
                       SPVM_MY_VAR* my_var = op_cur->uv.my_var;
                       
                       assert(my_var_length <= SPVM_LIMIT_C_MY_VARS);
@@ -1545,7 +1547,7 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                         my_var->index = my_var_length++;
                         
                         // op my_var
-                        SPVM_OP* op_my_var = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_MY_VAR, op_cur->file, op_cur->line);
+                        SPVM_OP* op_my_var = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_MY, op_cur->file, op_cur->line);
                         op_my_var->uv.my_var = my_var;
                         
                         // Add my var
